@@ -13,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import dataclasses
 import json  # type: ignore
+import logging
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
@@ -38,6 +38,14 @@ try:
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object, None]  # type: ignore
 
+try:
+    from google.api_core import client_logging  # type: ignore
+
+    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
+    CLIENT_LOGGING_SUPPORTED = False
+
+_LOGGER = logging.getLogger(__name__)
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -122,8 +130,8 @@ class BinauthzManagementServiceV1RestInterceptor:
     def pre_create_attestor(
         self,
         request: service.CreateAttestorRequest,
-        metadata: Sequence[Tuple[str, str]],
-    ) -> Tuple[service.CreateAttestorRequest, Sequence[Tuple[str, str]]]:
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.CreateAttestorRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for create_attestor
 
         Override in a subclass to manipulate the request or metadata
@@ -143,8 +151,8 @@ class BinauthzManagementServiceV1RestInterceptor:
     def pre_delete_attestor(
         self,
         request: service.DeleteAttestorRequest,
-        metadata: Sequence[Tuple[str, str]],
-    ) -> Tuple[service.DeleteAttestorRequest, Sequence[Tuple[str, str]]]:
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.DeleteAttestorRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for delete_attestor
 
         Override in a subclass to manipulate the request or metadata
@@ -153,8 +161,10 @@ class BinauthzManagementServiceV1RestInterceptor:
         return request, metadata
 
     def pre_get_attestor(
-        self, request: service.GetAttestorRequest, metadata: Sequence[Tuple[str, str]]
-    ) -> Tuple[service.GetAttestorRequest, Sequence[Tuple[str, str]]]:
+        self,
+        request: service.GetAttestorRequest,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.GetAttestorRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for get_attestor
 
         Override in a subclass to manipulate the request or metadata
@@ -172,8 +182,10 @@ class BinauthzManagementServiceV1RestInterceptor:
         return response
 
     def pre_get_policy(
-        self, request: service.GetPolicyRequest, metadata: Sequence[Tuple[str, str]]
-    ) -> Tuple[service.GetPolicyRequest, Sequence[Tuple[str, str]]]:
+        self,
+        request: service.GetPolicyRequest,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.GetPolicyRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for get_policy
 
         Override in a subclass to manipulate the request or metadata
@@ -191,8 +203,10 @@ class BinauthzManagementServiceV1RestInterceptor:
         return response
 
     def pre_list_attestors(
-        self, request: service.ListAttestorsRequest, metadata: Sequence[Tuple[str, str]]
-    ) -> Tuple[service.ListAttestorsRequest, Sequence[Tuple[str, str]]]:
+        self,
+        request: service.ListAttestorsRequest,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.ListAttestorsRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for list_attestors
 
         Override in a subclass to manipulate the request or metadata
@@ -214,8 +228,8 @@ class BinauthzManagementServiceV1RestInterceptor:
     def pre_update_attestor(
         self,
         request: service.UpdateAttestorRequest,
-        metadata: Sequence[Tuple[str, str]],
-    ) -> Tuple[service.UpdateAttestorRequest, Sequence[Tuple[str, str]]]:
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.UpdateAttestorRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for update_attestor
 
         Override in a subclass to manipulate the request or metadata
@@ -233,8 +247,10 @@ class BinauthzManagementServiceV1RestInterceptor:
         return response
 
     def pre_update_policy(
-        self, request: service.UpdatePolicyRequest, metadata: Sequence[Tuple[str, str]]
-    ) -> Tuple[service.UpdatePolicyRequest, Sequence[Tuple[str, str]]]:
+        self,
+        request: service.UpdatePolicyRequest,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[service.UpdatePolicyRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
         """Pre-rpc interceptor for update_policy
 
         Override in a subclass to manipulate the request or metadata
@@ -382,7 +398,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> resources.Attestor:
             r"""Call the create attestor method over HTTP.
 
@@ -393,8 +409,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.resources.Attestor:
@@ -408,6 +426,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseCreateAttestor._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_create_attestor(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseCreateAttestor._get_transcoded_request(
                 http_options, request
@@ -422,6 +441,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.CreateAttestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "CreateAttestor",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._CreateAttestor._get_response(
@@ -445,7 +491,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = resources.Attestor.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_create_attestor(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = resources.Attestor.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.create_attestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "CreateAttestor",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     class _DeleteAttestor(
@@ -483,7 +551,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ):
             r"""Call the delete attestor method over HTTP.
 
@@ -494,13 +562,16 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
             """
 
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseDeleteAttestor._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_delete_attestor(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseDeleteAttestor._get_transcoded_request(
                 http_options, request
@@ -511,6 +582,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = json_format.MessageToJson(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.DeleteAttestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "DeleteAttestor",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._DeleteAttestor._get_response(
@@ -563,7 +661,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> resources.Attestor:
             r"""Call the get attestor method over HTTP.
 
@@ -574,8 +672,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.resources.Attestor:
@@ -589,6 +689,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseGetAttestor._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_get_attestor(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseGetAttestor._get_transcoded_request(
                 http_options, request
@@ -599,6 +700,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.GetAttestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "GetAttestor",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._GetAttestor._get_response(
@@ -621,7 +749,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = resources.Attestor.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_get_attestor(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = resources.Attestor.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.get_attestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "GetAttestor",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     class _GetPolicy(
@@ -659,7 +809,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> resources.Policy:
             r"""Call the get policy method over HTTP.
 
@@ -670,8 +820,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.resources.Policy:
@@ -683,6 +835,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseGetPolicy._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_get_policy(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseGetPolicy._get_transcoded_request(
                 http_options, request
@@ -693,6 +846,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.GetPolicy",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "GetPolicy",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._GetPolicy._get_response(
@@ -715,7 +895,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = resources.Policy.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_get_policy(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = resources.Policy.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.get_policy",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "GetPolicy",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     class _ListAttestors(
@@ -753,7 +955,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> service.ListAttestorsResponse:
             r"""Call the list attestors method over HTTP.
 
@@ -764,8 +966,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.service.ListAttestorsResponse:
@@ -777,6 +981,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseListAttestors._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_list_attestors(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseListAttestors._get_transcoded_request(
                 http_options, request
@@ -787,6 +992,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.ListAttestors",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "ListAttestors",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._ListAttestors._get_response(
@@ -809,7 +1041,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = service.ListAttestorsResponse.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_list_attestors(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = service.ListAttestorsResponse.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.list_attestors",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "ListAttestors",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     class _UpdateAttestor(
@@ -848,7 +1102,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> resources.Attestor:
             r"""Call the update attestor method over HTTP.
 
@@ -859,8 +1113,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.resources.Attestor:
@@ -874,6 +1130,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseUpdateAttestor._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_update_attestor(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseUpdateAttestor._get_transcoded_request(
                 http_options, request
@@ -888,6 +1145,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.UpdateAttestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "UpdateAttestor",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._UpdateAttestor._get_response(
@@ -911,7 +1195,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = resources.Attestor.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_update_attestor(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = resources.Attestor.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.update_attestor",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "UpdateAttestor",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     class _UpdatePolicy(
@@ -950,7 +1256,7 @@ class BinauthzManagementServiceV1RestTransport(
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: Optional[float] = None,
-            metadata: Sequence[Tuple[str, str]] = (),
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
         ) -> resources.Policy:
             r"""Call the update policy method over HTTP.
 
@@ -961,8 +1267,10 @@ class BinauthzManagementServiceV1RestTransport(
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
-                metadata (Sequence[Tuple[str, str]]): Strings which should be
-                    sent along with the request as metadata.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
 
             Returns:
                 ~.resources.Policy:
@@ -974,6 +1282,7 @@ class BinauthzManagementServiceV1RestTransport(
             http_options = (
                 _BaseBinauthzManagementServiceV1RestTransport._BaseUpdatePolicy._get_http_options()
             )
+
             request, metadata = self._interceptor.pre_update_policy(request, metadata)
             transcoded_request = _BaseBinauthzManagementServiceV1RestTransport._BaseUpdatePolicy._get_transcoded_request(
                 http_options, request
@@ -988,6 +1297,33 @@ class BinauthzManagementServiceV1RestTransport(
                 transcoded_request
             )
 
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.UpdatePolicy",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "UpdatePolicy",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
             # Send the request
             response = (
                 BinauthzManagementServiceV1RestTransport._UpdatePolicy._get_response(
@@ -1011,7 +1347,29 @@ class BinauthzManagementServiceV1RestTransport(
             pb_resp = resources.Policy.pb(resp)
 
             json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
             resp = self._interceptor.post_update_policy(resp)
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = resources.Policy.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.binaryauthorization_v1.BinauthzManagementServiceV1Client.update_policy",
+                    extra={
+                        "serviceName": "google.cloud.binaryauthorization.v1.BinauthzManagementServiceV1",
+                        "rpcName": "UpdatePolicy",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
             return resp
 
     @property
